@@ -148,13 +148,13 @@ HoltWintersZZ <- function(x,
       }
     }
     if (select[1] > 0) {
-      alpha <- sol$p[1L]
+      alpha <- sol$par[1L]
     }
     if (select[2] > 0) {
-      beta <- sol$p[1L + select[1]]
+      beta <- sol$par[1L + select[1]]
     }
     if (select[3] > 0) {
-      gamma <- sol$p[1L + select[1] + select[2]]
+      gamma <- sol$par[1L + select[1] + select[2]]
     }
   }
 
@@ -410,7 +410,7 @@ zzhw <- function(x, lenx, alpha=NULL, beta=NULL, gamma=NULL, seasonal="additive"
 #' @param x Deprecated. Included for backwards compatibility.
 #' @param ... Other arguments passed to \code{forecast.ets}.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -440,7 +440,7 @@ zzhw <- function(x, lenx, alpha=NULL, beta=NULL, gamma=NULL, seasonal="additive"
 #'
 #' @references Hyndman and Athanasopoulos (2018) \emph{Forecasting: principles
 #' and practice}, 2nd edition, OTexts: Melbourne, Australia.
-#' \url{https://OTexts.org/fpp2/}
+#' \url{https://otexts.com/fpp2/}
 #' @keywords ts
 #' @examples
 #'
