@@ -68,9 +68,9 @@ simulate.ets <- function(object, nsim=length(object$x), seed=NULL, future=TRUE,
   }
 
   if (future) {
-    initstate <- object$state[length(object$x) + 1, ]
+    initstate <- object$states[length(object$x) + 1, ]
   } else { # choose a random starting point
-    initstate <- object$state[sample(1:length(object$x), 1), ]
+    initstate <- object$states[sample(1:length(object$x), 1), ]
   }
 
   if (bootstrap) {
@@ -78,7 +78,7 @@ simulate.ets <- function(object, nsim=length(object$x), seed=NULL, future=TRUE,
     e <- sample(res, nsim, replace = TRUE)
   }
   else if (is.null(innov)) {
-    e <- rnorm(nsim, 0, sqrt(object$sigma))
+    e <- rnorm(nsim, 0, sqrt(object$sigma2))
   } else if (length(innov) == nsim) {
     e <- innov
   } else {
@@ -539,7 +539,7 @@ simulate.lagwalk <- function(object, nsim=length(object$x), seed=NULL,
     e <- sample(res, nsim, replace = TRUE)
   }
   else if (is.null(innov)) {
-    se <- sqrt(object$sigma2*nsim + (nsim*object$par$drift.se)^2)
+    se <- sqrt(object$sigma2)
     e <- rnorm(nsim, 0, se)
   } else {
     e <- innov
@@ -579,7 +579,8 @@ simulate.lagwalk <- function(object, nsim=length(object$x), seed=NULL,
   }
 
   # Construct simulated ts
-  sim <- rep_len(start, nsim) + seq_len(nsim)*object$par$drift + cumulative_e
+  simdrift <- object$par$drift + rnorm(1,0,object$par$drift.se)
+  sim <- rep_len(start, nsim) + seq_len(nsim)*simdrift + cumulative_e
   if(!is.null(lambda)){
     sim <- InvBoxCox(sim, lambda)
   }
